==> mangokit-2.5.0-py3-none-any.whl: mangokit/uidrive/_base_data.py <==
# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-02-04 10:43
# @Author : 毛鹏
from typing import Optional

from uiautomation import WindowControl
from uiautomator2 import Device

from mangokit.data_processor import DataProcessor
from mangokit.database import MysqlConnect
from mangokit.enums import StatusEnum
from mangokit.models import MysqlConingModel


class BaseData:

    def __init__(self, test_data: DataProcessor):
        super().__init__()
        self.test_data = test_data

        self.mysql_config: Optional[MysqlConingModel | None] = None
        self.mysql_connect: Optional[MysqlConnect | None] = None

        self.url: Optional[str | None] = None
        self.is_open_url = False
        self.switch_step_open_url = False
        self.page = None
        self.context = None

        self.package_name: Optional[str | None] = None
        self.android: Optional[Device | None] = None
        self.is_open_app = False

        self.windows: Optional[None | WindowControl] = None

        self.download_path: Optional[str | None] = None
        self.screenshot_path: Optional[str | None] = None
        self.video_path: Optional[str | None] = None
        self.log = None

    def set_log(self, log):
        self.log = log
        return self

    def set_file_path(self, download_path, screenshot_path, video_path):
        self.download_path = download_path
        self.screenshot_path = screenshot_path
        self.video_path = video_path
        return self

    def set_step_open_url(self, switch_step_open_url: bool):
        self.switch_step_open_url = switch_step_open_url
        return self

    def set_url(self, url: str):
        self.url = url
        return self

    def set_page_context(self, page, context):
        self.page = page
        self.context = context

        return self

    def set_package_name(self, package_name: str):
        self.package_name = package_name
        return self

    def set_android(self, android: Device):
        self.android = android
        return self

    def setup(self, test_data=None) -> None:
        self.url = None
        self.page = None
        self.context = None

        self.package_name = None
        self.android = None
        self.mysql_connect = None
        self.mysql_config = None
        if not test_data:
            self.test_data = test_data

    async def async_base_close(self, test_data=None):
        if self.context:
            await self.context.close()
        if self.page:
            await self.page.close()
        if self.mysql_connect:
            self.mysql_connect.close()
        self.setup(test_data)

    def sync_base_close(self, test_data=None):
        if self.context:
            self.context.close()
        if self.page:
            self.page.close()
        if self.mysql_connect:
            self.mysql_connect.close()
        self.setup(test_data)

    def set_mysql(self, db_c_status, db_rud_status, mysql_config: MysqlConingModel):
        self.mysql_config = mysql_config
        if StatusEnum.SUCCESS.value in [db_c_status, db_rud_status]:
            self.mysql_connect = MysqlConnect(mysql_config,
                                              bool(db_c_status),
                                              bool(db_rud_status))
        return self

==> mangokit-2.6.15-py3-none-any.whl: mangokit/uidrive/_base_data.py <==
# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-02-04 10:43
# @Author : 毛鹏
from typing import Optional
from unittest.mock import MagicMock

import sys
from uiautomator2 import Device

if not sys.platform.startswith('win32'):
    WindowControl = MagicMock()
    print("警告: uiautomation 仅支持 Windows，当前环境已自动跳过")
else:
    from uiautomation import WindowControl

from mangokit.data_processor import DataProcessor
from mangokit.database import MysqlConnect
from mangokit.enums import StatusEnum
from mangokit.models import MysqlConingModel


class BaseData:

    def __init__(self, test_data: DataProcessor, log):
        super().__init__()
        self.test_data = test_data
        self.log = log
        self.download_path: Optional[str | None] = None
        self.screenshot_path: Optional[str | None] = None
        self.video_path: Optional[str | None] = None

        self.mysql_config: Optional[MysqlConingModel | None] = None
        self.mysql_connect: Optional[MysqlConnect | None] = None

        self.url: Optional[str | None] = None
        self.is_open_url = False
        self.switch_step_open_url = False
        self.page = None
        self.context = None

        self.package_name: Optional[str | None] = None
        self.android: Optional[Device | None] = None
        self.is_open_app = False

        self.windows: Optional[None | WindowControl] = None

    def set_file_path(self, download_path, screenshot_path, video_path):
        self.download_path = download_path
        self.screenshot_path = screenshot_path
        self.video_path = video_path
        return self

    def set_step_open_url(self, switch_step_open_url: bool):
        self.switch_step_open_url = switch_step_open_url
        return self

    def set_url(self, url: str):
        self.url = url
        return self

    def set_page_context(self, page, context):
        self.page = page
        self.context = context
        return self

    def set_package_name(self, package_name: str):
        self.package_name = package_name
        return self

    def set_android(self, android: Device):
        self.android = android
        return self

    def setup(self) -> None:
        self.url = None
        self.page = None
        self.context = None

        self.package_name = None
        self.android = None
        self.mysql_connect = None
        self.mysql_config = None

    async def async_base_close(self):
        if self.context:
            await self.context.close()
        if self.page:
            await self.page.close()
        if self.mysql_connect:
            self.mysql_connect.close()
        self.setup()

    def sync_base_close(self):
        if self.context:
            self.context.close()
        if self.page:
            self.page.close()
        if self.mysql_connect:
            self.mysql_connect.close()
        self.setup()

    def set_mysql(self, db_c_status, db_rud_status, mysql_config: MysqlConingModel):
        self.mysql_config = mysql_config
        if StatusEnum.SUCCESS.value in [db_c_status, db_rud_status]:
            self.mysql_connect = MysqlConnect(mysql_config,
                                              bool(db_c_status),
                                              bool(db_rud_status))
        return self
